@@ -162,6 +162,10 @@ class HTTPPasswordHandler(object):
         # Last resort: interactive prompt
         if not ui.interactive():
             raise util.Abort(_('mercurial_keyring: http authorization required but program used in non-interactive mode'))
+
+        if not fixed_user:
+            ui.status(_("Username not specified in .hg/hgrc. Keyring will not be used.\n"))
+            
         ui.write(_("http authorization required\n"))
         ui.status(_("realm: %s\n") % realm)
         if fixed_user:
@@ -204,6 +208,13 @@ class HTTPPasswordHandler(object):
         # *remote* repository, so does *not* contain any option from
         # local .hg/hgrc.
 
+        # TODO: mercurial 1.4.2 is claimed to resolve this problem
+        # (thanks to: http://hg.xavamedia.nl/mercurial/crew/rev/fb45c1e4396f) 
+        # so since this version workaround implemented below should
+        # not be necessary. As it will take some time until people
+        # migrate to >= 1.4.2, it would be best to implement
+        # workaround conditionally.
+        
         # Workaround: we recreate the repository object
         repo_root = ui.config("bundle", "mainreporoot")
 
